/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Configuration.java 3054 2008-04-30 15:41:13Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.osgi.plugins.launcher;

import java.io.File;
import java.io.Serializable;
import java.net.URL;
import java.util.List;
import java.util.Properties;

/**
 * This class keeps the configuration. It is a Serializable object then this
 * object can be read from the forked JVM if any.
 * @author Florent BENOIT
 */
public class Configuration implements Serializable {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 6556052376136830050L;

    /**
     * Waiting value after the start.
     */
    private long waitAfterStart = 0;

    /**
     * Waiting value after the stop.
     */
    private long waitAfterStop = 0;

    /**
     * List of bundles to start.
     */
    private List<URL> bundles = null;

    /**
     * List of bundles to start after a given delay.
     */
    private DelayedBundlePattern[] delayedBundles = null;

    /**
     * List of bundles to start in the given order (by their symbolic name).
     */
    private String[] startOrderBundles = null;

    /**
     * List of bundles to stop in the given order (by their symbolic name).
     */
    private String[] stopOrderBundles = null;

    /**
     * List of bundles to ignore (by their symbolic name).
     */
    private String[] excludedBundles = null;

    /**
     * List of path for the user Classpath.
     */
    private String[] userClasspath = null;


    /**
     * Name of the framework class.
     */
    private String frameworkClassname = null;

    /**
     * System properties.
     */
    private Properties systemProperties = null;

    /**
     * Working directory.
     */
    private File workingDirectory = null;

    /**
     * Config file URL.
     */
    private URL urlConfigFile = null;

    /**
     * @return the name of the framework class
     */
    public String getFrameworkClassname() {
        return frameworkClassname;
    }

    /**
     * Sets the name of the framework class.
     * @param frameworkClassname the name of the framework class
     */
    public void setFrameworkClassname(final String frameworkClassname) {
        this.frameworkClassname = frameworkClassname;
    }

    /**
     * @return Waiting value after the start.
     */
    public long getWaitAfterStart() {
        return waitAfterStart;
    }

    /**
     * @return List of bundles to start in the given order (by their symbolic
     *         name).
     */
    public String[] getStartOrderBundles() {
        return startOrderBundles;
    }

    /**
     * Sets the List of bundles to start in the given order (by their symbolic
     * name).
     * @param startOrderBundles the given list
     */
    public void setStartOrderBundles(final String[] startOrderBundles) {
        this.startOrderBundles = startOrderBundles;
    }

    /**
     * @return List of bundles to stop in the given order (by their symbolic
     *         name).
     */
    public String[] getStopOrderBundles() {
        return stopOrderBundles;
    }

    /**
     * Sets the List of bundles to stop in the given order (by their symbolic
     * name).
     * @param stopOrderBundles the given list
     */
    public void setStopOrderBundles(final String[] stopOrderBundles) {
        this.stopOrderBundles = stopOrderBundles;
    }

    /**
     * @return List of bundles to ignore(by their symbolic
     *         name).
     */
    public String[] getExcludedBundles() {
        return excludedBundles;
    }

    /**
     * Sets the List of bundles to ignore (by their symbolic
     * name).
     * @param excludedBundles the given list
     */
    public void setExcludedBundles(final String[] excludedBundles) {
        this.excludedBundles = excludedBundles;
    }

    /**
     * @return List of entry to add in the classpath.
     */
    public String[] getUserClasspath() {
        return userClasspath;
    }

    /**
     * Sets the List of entries to add in the classpath (by their symbolic
     * name).
     * @param userClasspath the given list
     */
    public void setUserClasspath(final String[] userClasspath) {
        this.userClasspath = userClasspath;
    }

    /**
     * Sets the List of bundles to start.
     * @param bundles the List of bundles to start.
     */
    public void setBundles(final List<URL> bundles) {
        this.bundles = bundles;
    }

    /**
     * @return the List of bundles to start.
     */
    public List<URL> getBundles() {
        return bundles;
    }

    /**
     * Sets Waiting value after the start.
     * @param waitAfterStart the given value in seconds
     */
    public void setWaitAfterStart(final long waitAfterStart) {
        this.waitAfterStart = waitAfterStart;
    }

    /**
     * @return List of bundles to start after a given delay.
     */
    public DelayedBundlePattern[] getDelayedBundles() {
        return delayedBundles;
    }

    /**
     * Sets the List of bundles to start after a given delay.
     * @param delayedBundles the given list
     */
    public void setDelayedBundles(final DelayedBundlePattern[] delayedBundles) {
        this.delayedBundles = delayedBundles;
    }

    /**
     * @return configuration file used by the framework.
     */
    public URL getURLConfigFile() {
        return urlConfigFile;
    }

    /**
     * Sets the configuration file used by the framework.
     * @param urlConfigFile URL of the config file
     */
    public void setURLConfigFile(final URL urlConfigFile) {
        this.urlConfigFile = urlConfigFile;
    }

    /**
     * Gets the working directory of the framework.
     * @return the working directory
     */
    public File getWorkingDirectory() {
        return workingDirectory;
    }

    /**
     * Sets the working directory.
     * @param workingDirectory the given directory
     */
    public void setWorkingDirectory(final File workingDirectory) {
        this.workingDirectory = workingDirectory;
    }

    /**
     * @return system properties to use for the launch of the framework
     */
    public Properties getSystemProperties() {
        return systemProperties;
    }

    /**
     * Sets the system properties to use for the launch of the framework.
     * @param systemProperties the set of properties
     */
    public void setSystemProperties(final Properties systemProperties) {
        this.systemProperties = systemProperties;
    }

    /**
     * @return Waiting value after the stop.
     */
    public long getWaitAfterStop() {
        return waitAfterStop;
    }

    /**
     * Sets the Waiting value after the stop.
     * @param waitAfterStop the wait value in seconds.
     */
    public void setWaitAfterStop(final long waitAfterStop) {
        this.waitAfterStop = waitAfterStop;
    }

}
